@@ -14,7 +14,7 @@ use XML::LibXML::XPathContext;
 use base qw(Class::Accessor::Fast);
 __PACKAGE__->mk_accessors(
     qw(libxml aws_access_key_id aws_secret_access_key secure ua err errstr timeout));
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 my $AMAZON_HEADER_PREFIX = 'x-amz-';
 my $METADATA_PREFIX      = 'x-amz-meta-';
@@ -106,7 +106,7 @@ sub list_bucket {
     if (%$conf) {
         $path .= "?"
             . join( '&',
-            map { "$_=" . urlencode( $conf->{$_} ) } keys %$conf );
+            map { "$_=" . $self->_urlencode( $conf->{$_} ) } keys %$conf );
     }
 
     my $xpc = $self->_send_request( 'GET', $path, {} );
